@@ -66,9 +66,9 @@ ConfWizard::ConfWizard( TQWidget* parent,  const char* name, bool modal )
     setNextEnabled( page_2, false );
     helpButton()->hide();
     
-    connect( buttonCreate, TQT_SIGNAL( clicked() ), this, TQT_SLOT( create() ) );
-    connect( buttonExample, TQT_SIGNAL( clicked() ), this, TQT_SLOT( example() ) );
-    connect( checkDatabase, TQT_SIGNAL( clicked() ), this, TQT_SLOT( useDatabase() ) );
+    connect( buttonCreate, TQ_SIGNAL( clicked() ), this, TQ_SLOT( create() ) );
+    connect( buttonExample, TQ_SIGNAL( clicked() ), this, TQ_SLOT( example() ) );
+    connect( checkDatabase, TQ_SIGNAL( clicked() ), this, TQ_SLOT( useDatabase() ) );
 }
 
 ConfWizard::~ConfWizard()
@@ -134,7 +134,7 @@ void ConfWizard::setupPage2()
     checkDatabase->setChecked( true );
 
     sqlwidget = new SqlWidget( true, page_2, "sqlwidget" );
-    connect( sqlwidget, TQT_SIGNAL( databaseWorking( bool ) ), this, TQT_SLOT( testSettings( bool ) ) );
+    connect( sqlwidget, TQ_SIGNAL( databaseWorking( bool ) ), this, TQ_SLOT( testSettings( bool ) ) );
         
     TQSpacerItem* spacer_5 = new TQSpacerItem( 0, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
     pageLayout_2->addWidget( checkDatabase );
