@@ -35,7 +35,7 @@ class TQString;
 class LabelPreview;
 class NewLabel : public TQDialog
 { 
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         NewLabel( TQWidget* parent = 0, const char* name = 0, bool change = FALSE, WFlags fl = 0 );
